classdef AcquisitionMode < int32
    %daq.di.enum.acquisitionmode: Input acquisition modes for
    % Digilent Analog Discovery. A 'mode' is the way Digilent refers to
    % the method by which samples are acquired into the ADC buffer.
    
    %   Copyright 2013 The MathWorks, Inc.
    
    enumeration
        Single      (0) % Perform a single buffer acquisition
        ScanShift   (1) % Continuous acquisition (FIFO). The trigger setting
                        % is ignored and the last sampled is at the end of
                        % the buffer. Use the FDwfAnalogInStatusSamplesValid
                        % function to determine the number of samples
                        % acquired
        ScanScreen  (2) % Perform acquisition into a circular buffer, 
                        % ignoring the trigger setting. Use the
                        % FDwfAnalogInStatusIndexWrite mode to fetch the
                        % index of the last element written
        Record      (3) % Perform acquisition for 'RecordLength' of time
    end
    methods
        function obj = AcquisitionMode(value)
            obj@int32(value);
        end
    end
end

