classdef GenerationMode < uint8
    %daq.di.enum.generationmode: Output generation modes for
    % Digilent Analog Discovery. A 'mode' is the way Digilent refers to
    % describe the waveform that will be generated by the DAC.
    
    %   Copyright 2013 The MathWorks, Inc.

    enumeration
        DC       (0)    % Use waveform-channel OFFSET to generate a DC value
        Sine     (1)    % Sinusoidal output
        Square   (2)    % Square-wave output
        Triangle (3)    % Triangle-wave output
        RampUp   (4)    % Ramp-Up and Hold
        RampDown (5)    % Hold and Ramp-Down
        Noise    (6)    % Bit-noise generator
        Custom   (30)   % Generate custom data: repeated waveforms
        Play     (31)   % Generate custom data: single unique stream
    end
    methods
        function obj = GenerationMode(value)
            obj@uint8(value);
        end
    end
end

