classdef InstrumentStatus < uint8
    %daq.di.enum.instrumentstatus: Possible states that can be entered and
    %returned by a query for Digilent Analog Discovery.

    % Note that these state-names are shared by Digilent's 'Acquisition' 
    % and 'Generation' systems.
    
    %   Copyright 2013 The MathWorks, Inc.
    
    enumeration
        Ready   (0) % Ready to be configured
        Arm     (1) % Armed and waiting for a trigger
        Done    (2) % Acquisition is done
        Trig    (3) % AnalogIn:     Triggering condition has been met
                    % AnalogOut:    Run for a specified amount of time
        Cfg     (4) % Performing configuration (prior to start)
        Prefill (5) % Performs buffer pre-fill before looking for a trigger
                    % condition
        NotDone (6)
        TrigDly (7) % Analog-Out Only: wait a specified duration before 
                    % triggering
        Error   (8)
        Busy    (9)
        Stop    (10)
    end
    methods
        function obj = InstrumentStatus(value)
            obj@uint8(value);
        end
    end
end

